# Linux

CC=gcc
CCFLAG=-O
LDFLAG=-O -s
AR=ar rs
RANLIB=touch
XINCLUDE=
SYSLIB=-lXpm -lX11 -lm

# where the library should be installed

LIB_DIR=/usr/lib
LIBMODE=644

HEADER_DIR=/usr/include
HEADERMODE=644

BIN_DIR=/usr/local/bin
BINMODE=711

MAN5_DIR=/usr/man/man5
MAN1_DIR=/usr/man/man1
DOC_DIR=/usr/local/lib
MANMODE=644

