/* Multiline labels. */

#include "forms.h"

FL_FORM *form;
FL_OBJECT *readyobj;

void create_form_0(void)
{
  FL_OBJECT *obj;
  form = fl_bgn_form(FL_NO_BOX,400.0,470.0);
  obj = fl_add_box(FL_UP_BOX,0.0,0.0,400.0,470.0,"");
    fl_set_object_color(obj,14,FL_COL1);
  obj = fl_add_text(FL_NORMAL_TEXT,140.0,310.0,120.0,120.0,"This is\na multi-line\nlabel");
    fl_set_object_boxtype(obj,FL_BORDER_BOX);
    fl_set_object_lalign(obj,FL_ALIGN_TOP);
  obj = fl_add_text(FL_NORMAL_TEXT,140.0,190.0,120.0,120.0,"This is\na multi-line\nlabel");
    fl_set_object_boxtype(obj,FL_BORDER_BOX);
    fl_set_object_color(obj,13,FL_COL1);
    fl_set_object_lsize(obj,FL_LARGE_SIZE);
    fl_set_object_lalign(obj,FL_ALIGN_CENTER);
  readyobj = obj = fl_add_button(FL_NORMAL_BUTTON,280.0,20.0,100.0,50.0,"I am sure\nthat I am\nReady");
    fl_set_object_lsize(obj,FL_SMALL_SIZE);
  obj = fl_add_text(FL_NORMAL_TEXT,260.0,190.0,120.0,120.0,"This is\na multi-line\nlabel");
    fl_set_object_boxtype(obj,FL_BORDER_BOX);
    fl_set_object_lalign(obj,FL_ALIGN_RIGHT);
  obj = fl_add_text(FL_NORMAL_TEXT,140.0,70.0,120.0,120.0,"This is\na multi-line\nlabel");
    fl_set_object_boxtype(obj,FL_BORDER_BOX);
    fl_set_object_lalign(obj,FL_ALIGN_BOTTOM);
  obj = fl_add_text(FL_NORMAL_TEXT,20.0,190.0,120.0,120.0,"This is\na multi-line\nlabel");
    fl_set_object_boxtype(obj,FL_BORDER_BOX);
  fl_end_form();
}

/*---------------------------------------*/


int
main(int argc, char *argv[])
{
  FL_OBJECT *obj;

  fl_initialize(argv[0], "FormDemo", 0, 0 ,&argc, argv);
  create_form_0();
  fl_show_form(form,FL_PLACE_CENTER,FL_NOBORDER,NULL);
  do obj = fl_do_forms(); while (obj != readyobj);
  fl_hide_form(form);
  return 0;
}
