#include "forms.h"

int
main(int argc, char *argv[])
{
  FL_FORM *form;
  FL_OBJECT *but, *obj;

  fl_initialize(argv[0], "FormDemo", 0, 0 ,&argc, argv);
  form = fl_bgn_form(FL_UP_BOX,400,450);
  fl_add_input(FL_MULTILINE_INPUT,30,270,340,150,"");
  fl_add_input(FL_MULTILINE_INPUT,30,90,340,150,"");
  but = fl_add_button(FL_NORMAL_BUTTON,160,30,80,30,"Exit");
  fl_end_form();
  fl_show_form(form,FL_PLACE_CENTER,FL_NOBORDER,NULL);
  do  obj = fl_do_forms(); while (obj != but);
  return 0;
}
