/* A box with two buttons and a text. Simple boxes like this
   are very usefull for asking questions to the user.
*/

#include "forms.h"

int
main(int argc, char *argv[])
{
   FL_FORM *form;
   FL_OBJECT *yes, *no, *but;
  
  fl_initialize(argv[0], "FormDemo", 0, 0 ,&argc, argv);
  form = fl_bgn_form(FL_UP_BOX,320,120);
    fl_add_box(FL_NO_BOX,160,80,0,0,"Do you want to Quit?");
    yes = fl_add_button(FL_NORMAL_BUTTON,40,20,80,30,"Yes");
    no  = fl_add_button(FL_NORMAL_BUTTON,200,20,80,30,"No");
  fl_end_form();

  fl_show_form(form,FL_PLACE_MOUSE,FL_NOBORDER,NULL);
  do but = fl_do_forms(); while (but != yes);
  fl_hide_form(form);
  return 0;
}

