/* Showing all different charts */

/* Form definition file generated with fdesign. */

#include "forms.h"

FL_FORM *form;

FL_OBJECT
        *barchart,
        *linechart,
        *filledchart,
        *piechart,
        *specialpiechart,
        *exitbut,
        *horbarchart,
        *spikechart;

void create_form_form(void)
{
  FL_OBJECT *obj;
  form = fl_bgn_form(FL_NO_BOX,940.0,360.0);
  obj = fl_add_box(FL_UP_BOX,0.0,0.0,940.0,360.0,"");
  barchart = obj = fl_add_chart(FL_BAR_CHART,20.0,200.0,210.0,140.0,"BAR_CHART");
    fl_set_object_boxtype(obj,FL_RSHADOW_BOX);
  linechart = obj = fl_add_chart(FL_LINE_CHART,250.0,200.0,210.0,140.0,"LINE_CHART");
    fl_set_object_boxtype(obj,FL_RSHADOW_BOX);
  filledchart = obj = fl_add_chart(FL_FILLED_CHART,250.0,30.0,210.0,140.0,"FILLED_CHART");
    fl_set_object_boxtype(obj,FL_RSHADOW_BOX);
  piechart = obj = fl_add_chart(FL_PIE_CHART,480.0,30.0,210.0,140.0,"PIE_CHART");
    fl_set_object_boxtype(obj,FL_RSHADOW_BOX);
  specialpiechart = obj = fl_add_chart(FL_SPECIALPIE_CHART,710.0,200.0,210.0,140.0,"SPECIALPIE_CHART");
    fl_set_object_boxtype(obj,FL_RSHADOW_BOX);
  exitbut = obj = fl_add_button(FL_NORMAL_BUTTON,750.0,70.0,140.0,30.0,"Exit");
  horbarchart = obj = fl_add_chart(FL_HORBAR_CHART,20.0,30.0,210.0,140.0,"HORBAR_CHART");
    fl_set_object_boxtype(obj,FL_RSHADOW_BOX);
  spikechart = obj = fl_add_chart(FL_SPIKE_CHART,480.0,200.0,210.0,140.0,"SPIKE_CHART");
    fl_set_object_boxtype(obj,FL_RSHADOW_BOX);
  fl_end_form();
}

/*---------------------------------------*/

void fill_in(FL_OBJECT *ob)
{
  int c = FL_BLACK;
  fl_add_chart_value(ob,15.0,"item 1",++c);
  fl_add_chart_value(ob,5.0,"item 2",++c);
  fl_add_chart_value(ob,0.0,"item 3",++c);
  fl_add_chart_value(ob,-10.0,"item 4",++c);
  fl_add_chart_value(ob,25.0,"item 5",++c);
  fl_add_chart_value(ob,12.0,"item 6",++c);
}

int
main(int argc, char *argv[])
{

  fl_initialize(argv[0], "FormDemo", 0, 0 ,&argc, argv);
  create_form_form();
  fill_in(barchart);
  fill_in(horbarchart);
  fill_in(linechart);
  fill_in(filledchart);
  fill_in(spikechart);
  fill_in(piechart);
  fill_in(specialpiechart);
  fl_show_form(form,FL_PLACE_CENTER,FL_NOBORDER,NULL);
  fl_do_forms();
  return 0;
}
