/*
 * Class Crossbutton header file
 */
#ifndef CROSSBUT_H
#define CROSSBUT_H

#define FL_CROSSBUTTON    2000

#define FL_CROSSBUTTON_BW  2

extern FL_OBJECT *fl_add_crossbutton(int, FL_Coord, FL_Coord, 
                    FL_Coord, FL_Coord, const char *);

extern FL_OBJECT *fl_create_crossbutton(int, FL_Coord, FL_Coord,
                   FL_Coord, FL_Coord, const char *);

#endif
