/* This demo shows the different types of sliders */

#include "forms.h"


FL_FORM *form;

FL_OBJECT
        *exitobj;

void create_form_form(void)
{
  FL_OBJECT *obj;

  form = fl_bgn_form(FL_NO_BOX,780,320);
  obj = fl_add_box(FL_UP_BOX,0,0,780,320,"");
    fl_set_object_color(obj,10,FL_COL1);
  obj = fl_add_box(FL_SHADOW_BOX,20,20,360,270,"SLIDER");
    fl_set_object_color(obj,FL_SLATEBLUE,47);
    fl_set_object_lalign(obj,FL_ALIGN_TOP);
    fl_set_object_lstyle(obj,FL_BOLD_STYLE);
  obj = fl_add_box(FL_SHADOW_BOX,390,20,370,270,"VALSLIDER");
    fl_set_object_color(obj,FL_SLATEBLUE,47);
    fl_set_object_lalign(obj,FL_ALIGN_TOP);
    fl_set_object_lstyle(obj,FL_BOLD_STYLE);
  obj = fl_add_slider(FL_VERT_SLIDER,30,50,40,220,"vert");
    fl_set_object_color(obj,FL_INDIANRED,10);
    fl_set_object_lsize(obj,FL_SMALL_SIZE);
  obj = fl_add_slider(FL_VERT_FILL_SLIDER,80,50,40,220,"vert_fill");
    fl_set_object_color(obj,FL_INDIANRED,10);
    fl_set_object_lsize(obj,FL_SMALL_SIZE);
  obj = fl_add_slider(FL_HOR_SLIDER,180,230,190,40,"hor");
    fl_set_object_color(obj,FL_INDIANRED,10);
    fl_set_object_lsize(obj,FL_SMALL_SIZE);
  obj = fl_add_slider(FL_HOR_FILL_SLIDER,180,170,190,40,"hor_fill");
    fl_set_object_color(obj,FL_INDIANRED,10);
    fl_set_object_lsize(obj,FL_SMALL_SIZE);
  obj = fl_add_valslider(FL_VERT_NICE_SLIDER,610,50,30,220,"vert_nice");
    fl_set_object_boxtype(obj,FL_FLAT_BOX);
    fl_set_object_color(obj,FL_SLATEBLUE,FL_INDIANRED);
    fl_set_object_lsize(obj,FL_SMALL_SIZE);
  obj = fl_add_valslider(FL_VERT_FILL_SLIDER,660,50,40,220,"vert_fill");
    fl_set_object_color(obj,FL_INDIANRED,10);
    fl_set_object_lsize(obj,FL_SMALL_SIZE);
  obj = fl_add_valslider(FL_HOR_SLIDER,400,230,190,40,"hor");
    fl_set_object_color(obj,FL_INDIANRED,10);
    fl_set_object_lsize(obj,FL_SMALL_SIZE);
  obj = fl_add_valslider(FL_HOR_FILL_SLIDER,400,170,190,40,"hor_fill");
    fl_set_object_color(obj,FL_INDIANRED,10);
    fl_set_object_lsize(obj,FL_SMALL_SIZE);
  exitobj = obj = fl_add_button(FL_NORMAL_BUTTON,450,50,100,30,"Exit");
    fl_set_object_color(obj,FL_INDIANRED,1);
  obj = fl_add_slider(FL_VERT_NICE_SLIDER,130,50,30,220,"vert_nice");
    fl_set_object_boxtype(obj,FL_FLAT_BOX);
    fl_set_object_color(obj,12,FL_INDIANRED);
    fl_set_object_lsize(obj,FL_SMALL_SIZE);
  obj = fl_add_slider(FL_HOR_NICE_SLIDER,180,120,190,30,"hor_nice");
    fl_set_object_boxtype(obj,FL_FLAT_BOX);
    fl_set_object_color(obj,12,FL_INDIANRED);
    fl_set_object_lsize(obj,FL_SMALL_SIZE);
  obj = fl_add_valslider(FL_HOR_NICE_SLIDER,400,120,190,30,"hor_nice");
    fl_set_object_boxtype(obj,FL_FLAT_BOX);
    fl_set_object_color(obj,12,FL_INDIANRED);
    fl_set_object_lsize(obj,FL_SMALL_SIZE);
  obj = fl_add_valslider(FL_VERT_SLIDER,710,50,40,220,"vert");
    fl_set_object_color(obj,FL_INDIANRED,10);
    fl_set_object_lsize(obj,FL_SMALL_SIZE);
  fl_end_form();
}

/*---------------------------------------*/

void create_the_forms(void)
{
  create_form_form(void);
}

/*---------------------------------*/

int
main(int argc, char *argv[])
{
  FL_OBJECT *obj;

  fl_initialize(argv[0], "FormDemo", 0, 0 ,&argc, argv);
  create_the_forms();

  fl_show_form(form,FL_PLACE_CENTER,FL_NOBORDER,NULL);
  do obj = fl_do_forms(); while (obj != exitobj);
  fl_hide_form(form);
  return 0;
}

